<?php

use eftec\bladeone\BladeOne;

include "lib/BladeOne.php"; // you should change it and indicates the correct route.


/**
 * Register all actions and filters for the plugin
 *
 * @link       https://www.chiptuningreseller.com
 * @since      3.1.2
 *
 * @package    Ctr
 * @subpackage Ctr/includes
 */

/**
 * Register all actions and filters for the plugin.
 *
 * Maintain a list of all hooks that are registered throughout
 * the plugin, and register them with the WordPress API. Call the
 * run function to execute the list of actions and filters.
 *
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
class CTR_Templator {
    private $blade;

	/**
	 * The array of actions registered with WordPress.
	 *
	 * @since    3.1.2
	 * @access   protected
	 * @var      array    $actions    The actions registered with WordPress to fire when the plugin loads.
	 */
    protected $actions;
    

	protected $cache_path;
	protected $views_path;

	/**
	 * The array of filters registered with WordPress.
	 *
	 * @since    3.1.2
	 * @access   protected
	 * @var      array    $filters    The filters registered with WordPress to fire when the plugin loads.
	 */
	protected $filters;

	/**
	 * Initialize the collections used to maintain the actions and filters.
	 *
	 * @since    3.0.0
	 */
	public function __construct($viewPath = null, $cachePath = null)
    {
        $this->views_path = $viewPath !== null ? $viewPath : plugin_dir_path( dirname( __FILE__ ) ) . 'public/templates/';
        $this->cache_path = $cachePath !== null ? $cachePath : plugin_dir_path( dirname( __FILE__ ) ) . 'public/cache/';
    }

    public function init() {
        $this->blade = new BladeOne($this->views_path, $this->cache_path, BladeOne::MODE_AUTO);
        $this->blade->addAliasClasses('CtrHelpers', 'Ctr_Helpers');
    }

    public function setViewPath($viewPath) {
        $this->views_path = $viewPath !== null ? $viewPath : plugin_dir_path( dirname( __FILE__ ) ) . 'public/templates/';
    }

    /**
     * Render template data
     */
    public function renderData($templateData, $data)
    {
        $this->setTags($data);
        $this->replaceTags($templateData);

        echo $this->template;
    }

    /**
     * Render template from file
     */
    public function renderFile($filePath, $data, $viewPath = null)
    {
        $this->setViewPath($viewPath);
        $this->init();
        echo $this->blade->run($filePath, $data);
    }

    /**
     * Return template from file
     */
    public function returnFile($filePath, $data, $viewPath = null)
    {
        $this->setViewPath($viewPath);
        $this->init();
        return $this->blade->run($filePath, $data);
    }

    /**
     * Set a tag that needs to be replaced
     */
    public function setTags($data)
    {
        foreach($data as $key => $val) {
            $this->tags[$key] = $val;
        }
    }

    /**
     * Replace the tags with the actual values in the template file
     */
    private function replaceTags($templateData)
    {
        foreach ($this->tags as $tag => $value) {
            $templateData = str_replace('{{ ' . $tag . ' }}', $value, $templateData);
        }

        $this->template = $templateData;
        return true;
    }


    /**
     * Get a file from disk and parse it
     */
    public function getFile($file)
    {
        if(file_exists($file))
        {
            $file = file_get_contents($file);
            return $file;
        }
        else
        {
            return false;
        }
    }

    /**
     * Clear the cached templates
     */
    public function clear_cache() {
        
        if (!is_dir($this->cache_path)) {
            throw new InvalidArgumentException("$this->cache_path must be a directory");
        }
        if (substr($this->cache_path, strlen($this->cache_path) - 1, 1) != '/') {
            $this->cache_path .= '/';
        }
        $files = glob($this->cache_path . '*', GLOB_MARK);
        foreach ($files as $file) {
            if (is_dir($file)) {
                // no dirs here... so not needed
            } else {
                unlink($file);
            }
        }
        return true;
    }


    /** Copy all the template files so they can be customized and used by the user */
    public function copy_templates($destination, $src = null, $silent = false) {
        $source = null != $src ? $src : $this->views_path;
        if (!is_dir($destination)) {
            mkdir($destination);
        }
        $skipped = self::recurse_copy($source, $destination, $silent);
        if($skipped) {
            return $skipped;
        }
    }

    //@todo: put in helpers
    private static function recurse_copy($src, $dst, $silent)
    {
        $dir = opendir($src);
        $skipped = 0;
        @mkdir($dst, 0755);
        while (false !== ($file = readdir($dir))) {
            if (($file != '.') && ($file != '..')) {
                if (is_dir($src . '/' . $file)) {
                    self::recurse_copy($src . '/' . $file, $dst . '/' . $file, $silent);
                } else {
                    
                    if(!is_file($dst . '/' . $file)) {

                        copy($src . '/' . $file, $dst . '/' . $file);
                        if(!$silent) { echo "\r\nCOPIED " . $file . ' to ' . $dst; }
                    } else {
                        if(!$silent) { echo "\r\nSKIPPED " . $file . ' copying file to ' . $dst; }
                        $skipped++;
                    }
                }
            }
        }
        closedir($dir);
        return $skipped;
    }
    
    //@todo: put in helpers
    public static function deleteDir($dirPath)
    {
        if (!is_dir($dirPath)) {
            throw new InvalidArgumentException("$dirPath must be a directory");
        }
        if (substr($dirPath, strlen($dirPath) - 1, 1) != '/') {
            $dirPath .= '/';
        }
        $files = glob($dirPath . '*', GLOB_MARK);
        foreach ($files as $file) {
            if (is_dir($file)) {
                self::deleteDir($file);
            } else {
                unlink($file);
            }
        }
        rmdir($dirPath);
    }


}
