<?php

/* ChiptuningReseller class */
if(strpos($_SERVER['SERVER_NAME'], 'ctr-wordpress.test') !== false) {
    define('TESTMODE', true);
	define('BASEURL', "http://ctr.test/api/v1/");
	define('API_ES_URL', "http://staging.chiptuningreseller.com/api/search/");
	define('API_SEARCH_URL', BASEURL . 'cardata/search');
	define('API_URL', BASEURL . 'cardata/');
} else {
    define('TESTMODE', false);
	define('BASEURL', "https://app.chiptuningreseller.com/api/v1/");
	define('API_ES_URL', "https://app.chiptuningreseller.com/api/search/");
	define('API_SEARCH_URL', BASEURL . 'cardata/search');
	define('API_URL', BASEURL . 'cardata/');
}

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://www.chiptuningreseller.com
 * @since      3.0.0
 *
 * @package    Ctr
 * @subpackage Ctr/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
class Ctr {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    3.0.0
	 * @access   protected
	 * @var      Ctr_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    3.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    3.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    3.0.0
	 */
	public function __construct() {
		if ( defined( 'CTR_VERSION' ) ) {
			$this->version = CTR_VERSION;
		} else {
			$this->version = '3.0.0';
		}
		$this->plugin_name = 'ctr';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Ctr_Loader. Orchestrates the hooks of the plugin.
	 * - Ctr_i18n. Defines internationalization functionality.
	 * - Ctr_Admin. Defines all hooks for the admin area.
	 * - Ctr_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    3.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-i18n.php';

		/**
		 * URL Rewriting functionalities
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-rewrite.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-ctr-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-ctr-public.php';

		$this->loader = new Ctr_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Ctr_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    3.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Ctr_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    3.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {
		$plugin_admin = new Ctr_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'create_admin_menu' );
		$this->loader->add_action( 'wp_ajax_flush_cache', $plugin_admin, 'flush_cache' );
		$this->loader->add_action( 'wp_ajax_flush_media', $plugin_admin, 'flush_media' );
		$this->loader->add_action( 'wp_ajax_flush_templates', $plugin_admin, 'flush_templates' );
		$this->loader->add_action( 'wp_ajax_copy_templates', $plugin_admin, 'copy_templates' );
		$this->loader->add_action( 'wp_ajax_reset_template_file', $plugin_admin, 'reset_template_file' );
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    3.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_rewrite = new CTR_Rewrite();
		$plugin_public = new Ctr_Public( $this->get_plugin_name(), $this->get_version(), $plugin_rewrite );
		
		$this->loader->add_action( 'init', $plugin_public, 'rewrite_urls', 10, 0);
		$this->loader->add_filter( 'query_vars', $plugin_public, 'set_custom_query_vars' );
		//$this->loader->add_action( 'template_include', $plugin_public, 'activate_theme_template', 1);

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

		$this->loader->add_action( 'template_redirect', $plugin_public, 'handleFront' );
		$this->loader->add_shortcode( 'ctr_show_selector', $plugin_public, 'activate_dropdown_shortcode', 5);
		$this->loader->add_shortcode( 'ctr_show_search', $plugin_public, 'activate_search_shortcode', 8);

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    3.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     3.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     3.0.0
	 * @return    Ctr_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     3.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
